#Exception classes
class VersionError(Exception):
    pass

class FunctionError(Exception):
    pass

class LanguageError(Exception):
    pass

class ModuleError(Exception):
    pass

class InvalidVoiceError(Exception):
    pass

class InvalidTypeError(Exception):
    pass

class InvalidHashSecurityValue(Exception):
    pass

class UnknownError(Exception):
    pass

class InvalidPPBool(Exception):
    pass

class InvalidFormat(Exception):
    pass

class FFmpegError(Exception):
    pass